/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_SERVICE = 258,
     T_PORT = 259,
     T_EXEC = 260,
     T_PROTO = 261,
     T_UDP = 262,
     T_TCP = 263,
     T_UID = 264,
     T_GID = 265,
     T_BACKLOG = 266,
     T_INSTANCES = 267,
     T_DEFAULT = 268,
     T_NICE = 269,
     T_INTERFACE = 270,
     T_FISH = 271,
     T_CHROOT = 272,
     T_SERVER = 273,
     T_DIR = 274,
     T_RPC = 275,
     T_VERSION = 276,
     T_NAME = 277,
     T_WRAP = 278,
     T_CAPS = 279,
     T_FAMILY = 280,
     T_IPV4 = 281,
     T_IPV6 = 282,
     T_INITGROUPS = 283,
     T_BANNER = 284,
     T_ECHO = 285,
     T_DISCARD = 286,
     T_FILTER = 287,
     T_CHARGEN = 288,
     T_LOOPBACK = 289,
     T_RLIMIT = 290,
     T_LIM_CPU = 291,
     T_LIM_FSIZE = 292,
     T_LIM_DATA = 293,
     T_LIM_STACK = 294,
     T_LIM_CORE = 295,
     T_LIM_RSS = 296,
     T_LIM_NPROC = 297,
     T_LIM_NOFILE = 298,
     T_LIM_MEMLOCK = 299,
     T_LIM_INFINITY = 300,
     T_SOFT = 301,
     T_HARD = 302,
     T_LOG = 303,
     T_PIPE = 304,
     T_SYSLOG = 305,
     T_PATH = 306,
     T_MODE = 307,
     T_ACCEPT = 308,
     T_DENY = 309,
     T_CLOSE = 310,
     T_EXIT = 311,
     T_NUMERIC = 312,
     T_QSTRING = 313,
     T_IPADDR = 314
   };
#endif
#define T_SERVICE 258
#define T_PORT 259
#define T_EXEC 260
#define T_PROTO 261
#define T_UDP 262
#define T_TCP 263
#define T_UID 264
#define T_GID 265
#define T_BACKLOG 266
#define T_INSTANCES 267
#define T_DEFAULT 268
#define T_NICE 269
#define T_INTERFACE 270
#define T_FISH 271
#define T_CHROOT 272
#define T_SERVER 273
#define T_DIR 274
#define T_RPC 275
#define T_VERSION 276
#define T_NAME 277
#define T_WRAP 278
#define T_CAPS 279
#define T_FAMILY 280
#define T_IPV4 281
#define T_IPV6 282
#define T_INITGROUPS 283
#define T_BANNER 284
#define T_ECHO 285
#define T_DISCARD 286
#define T_FILTER 287
#define T_CHARGEN 288
#define T_LOOPBACK 289
#define T_RLIMIT 290
#define T_LIM_CPU 291
#define T_LIM_FSIZE 292
#define T_LIM_DATA 293
#define T_LIM_STACK 294
#define T_LIM_CORE 295
#define T_LIM_RSS 296
#define T_LIM_NPROC 297
#define T_LIM_NOFILE 298
#define T_LIM_MEMLOCK 299
#define T_LIM_INFINITY 300
#define T_SOFT 301
#define T_HARD 302
#define T_LOG 303
#define T_PIPE 304
#define T_SYSLOG 305
#define T_PATH 306
#define T_MODE 307
#define T_ACCEPT 308
#define T_DENY 309
#define T_CLOSE 310
#define T_EXIT 311
#define T_NUMERIC 312
#define T_QSTRING 313
#define T_IPADDR 314




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 99 "grammar.y"
typedef union YYSTYPE {
	long num;
	char *cp;
	struct passwd *uid;
	struct group *gid;
	struct opmetalist *opml;
	struct opmeta *opm;
	rlim_t rl;
} YYSTYPE;
/* Line 1285 of yacc.c.  */
#line 165 "grammar.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;



